Used inside a mark_*() encoding to reference a variable produced by the
layer's statistical transform rather than a raw data column, e.g.
y = after_stat(count) or y = after_stat(density).
Used inside a mark_*() encoding to reference a variable produced by the
layer's statistical transform rather than a raw data column, e.g.
y = after_stat(count) or y = after_stat(density).